import json
import tempfile
import time

from pyrogram import Client
from random import randint
from pathlib import Path
from alive_progress import alive_bar
from pyrogram.types import InputPhoneContact


class Telegram:

    def __init__(self) -> None:
        """
        This class is based on the module pyrogram
        """
        self.user = None
        self.message = None
        self.image = None

    def connect_user(self,
                     api_id: int,
                     api_hash: str,
                     phone_number: str
                     ) -> None:
        """
        Method for connecting an account

        Args:
            api_id (int):
            api_hash (str):
            phone_number (str): your phone number

        api_id and api_hash can be obtained from this link by
        creating an application:
            https://my.telegram.org/auth
        """
        self.user = Client("my_account",
                           api_id=api_id,
                           api_hash=api_hash,
                           phone_number=phone_number
                           ).start()

    def set_message(self, message: str) -> None:
        """
        Set the message to be used in further mailing

        Args:
            message (str): message text
        """
        self.message = message

    def set_file_message(self, path: str) -> None:
        """
        Get message text from .txt or .md file

        Args:
            path (str): path to file
        """
        if Path(path).is_file() and (Path(path).suffix == ".md" or Path(path).suffix == ".txt"):
            md_str = ''
            with open(path, "r", encoding="utf-8") as file:
                for line in file:
                    md_str += line
            self.message = md_str

    def set_image(self, path) -> None:
        """
        Attach image to message

        Args:
            path (str): image path
        """
        if Path(path).is_file() and (Path(path).suffix == ".png" or Path(path).suffix == ".jpg"
                                     or Path(path).suffix == ".jpeg"):
            self.image = path

    def check_message(self) -> None:
        """
        Check the finished message

        Sends a ready-made text to himself
        in private messages
        """
        if self.image is None:
            self.user.send_message('me', self.message)
        else:
            self.user.send_photo('me', self.image, caption=self.message)

    def get_chats(self) -> list:
        """
        Get a list of all chats with their name and id

        Return:
            list: id list
        """
        chats = []
        for dialog in self.user.get_dialogs():
            chats.append({'dialog': dialog.chat.first_name or dialog.chat.title, 'id': dialog.chat.id})
        return chats

    def get_me(self) -> Client:
        """
        Get your user class Client from pyrogram

        Return:
             Client: class from pyrogram module
        """
        return self.user

    def start_selective_spam(self,
                             chats: list,
                             message: str = None,
                             image: str = None,
                             delay_time: float = 1.5
                             ) -> None:
        """
        Start mailing to all elements of the array (1 message each)

        Args:
            chats (list): ID of all users
            message (str): set a text message
            image (str): set image to message
            delay_time (float): delay time between sending emails
        """
        if message is not None:
            self.set_message(message)
        if image is not None:
            self.set_image(image)

        with alive_bar(len(chats), force_tty=True) as bar:
            for id in chats:
                if str(id).isdigit():
                    if self.image is not None:
                        self.user.send_photo(id, self.image, caption=self.message)
                        time.sleep(delay_time)
                        bar()
                    else:
                        self.user.send_message(id, self.message)
                        time.sleep(delay_time)
                        bar()
                else:
                    print(f'{id} is not ID')

    def start_all_spam(self,
                       message: str = None,
                       image: str = None,
                       delay_time: float = 1.5
                       ) -> None:
        """
        Start sending to all chats you've ever interacted in

        Args:
            message (str): set a text message
            image (str): set image to message
            delay_time (float): delay time between sending emails
        """
        if message is not None:
            self.set_message(message)
        if image is not None:
            self.set_image(image)

        all_chats = self.get_chats()
        with alive_bar(len(all_chats), force_tty=True) as bar:
            for chat in all_chats:
                if self.image is None:
                    self.user.send_message(chat['id'], self.message)
                    time.sleep(delay_time)
                    bar()
                else:
                    self.user.send_photo(chat['id'], self.image, caption=self.message)
                    time.sleep(delay_time)
                    bar()

    def start_bombing(self,
                      user_id: int,
                      amount: int,
                      message: str = None,
                      image: str = None,
                      delay_time: float = 1.5
                      ) -> None:
        """
        Start bombarding one user with messages

        Args:
             user_id (int): user ID
             amount (int): number of sent messages
             message (str): set a text message
             image (str): set image to message
             delay_time (float): delay time between sending emails
        """
        if message is not None:
            self.set_message(message)
        if image is not None:
            self.set_image(image)

        with alive_bar(amount, force_tty=True) as bar:
            for i in range(amount):
                if self.image is not None:
                    self.user.send_photo(user_id, self.image, caption=self.message)
                    time.sleep(delay_time)
                    bar()
                else:
                    self.user.send_message(user_id, self.message)
                    time.sleep(delay_time)
                    bar()

    def send_message(self,
                     user_id: int,
                     message: str = None,
                     image: str = None
                     ) -> None:
        """
        Normally send a message to a user

        Args:
            user_id (int): user ID
            message (str): set a text message
            image (str): set image to message
        """
        if message is not None:
            self.set_message(message)
        if image is not None:
            self.set_image(image)

        if self.image is not None:
            self.user.send_photo(user_id, self.image, caption=self.message)
        else:
            self.user.send_message(user_id, self.message)

    def get_id_by_phone(self, phone_num: str) -> int:
        """
        Method for getting a user's ID by his number (adds this contact to you in telegram chats,
        and then deletes it - it's better not to test on your contacts)

        Args:
            phone_num (str): phone number of interest
        Return:
            str: ID by number
        """
        temp_contact_name = tempfile.NamedTemporaryFile().name.split('\\')[-1]
        good_res = list()
        self.user.import_contacts([InputPhoneContact(phone=phone_num, first_name=temp_contact_name)])
        contacts = self.user.get_contacts()
        for contact in contacts:
            contact_data = json.loads(str(contact))
            if contact_data['first_name'] == temp_contact_name:
                good_res.append(contact_data)
                self.user.delete_contacts(contact_data['id'])

        try:
            good_res = int(good_res[0]['id'])
        except:
            good_res = None

        return good_res



import vk_api
import time

from pathlib import Path
from random import randint
from alive_progress import alive_bar


class Vkontakte:

    def __init__(self) -> None:
        """
        This class is based on the module vk_api
        """
        self.user = None
        self.vk = None
        self.message = None
        self.image = None

    def connect_user(self, token: str) -> None:
        """
        Method for connecting an account

        Args:
            token (str): a personal token of your account with
            access to messages, friends and access at any time.

        The token can be obtained from the link:
            https://vkhost.github.io/
        """
        self.user = vk_api.VkApi(token=token)
        self.vk = self.user.get_api()

    def get_chats_id(self) -> list:
        """
        Method for getting list of id of all messages

        Return:
            list: message id list
        """
        chats = []
        for chat in self.vk.messages.getConversations(extended=1)['items']:
            chats.append(chat['conversation']['peer']['id'])
        for chat in self.vk.messages.getConversations(extended=1)['profiles']:
            chats.append(chat['id'])
        return chats

    def get_name_by_id(self, user_id: int) -> list:
        """
        Method for obtaining data about a person by his ID

        Args:
            user_id (int): user ID

        Return:
            list: person information
        """
        user = self.user.method("users.get", {"user_ids": user_id})[0]
        return user

    def set_message(self, message: str) -> None:
        """
        Set the message to be used in further mailing

        Args:
            message (str): message text
        """
        self.message = message

    def set_file_message(self, path: str) -> None:
        """
        Get message text from .txt or .md file

        Args:
            path (str): path to file
        """
        if Path(path).is_file() and (Path(path).suffix == ".txt" or Path(path).suffix == ".md"):
            md_str = ''
            with open(path, "r", encoding="utf-8") as file:
                for line in file:
                    md_str += line
            self.message = md_str

    def check_message(self) -> None:
        """
        Check the finished message

        Sends a ready-made text to himself
        in private messages
        """
        self.vk.messages.send(user_id=self.vk.users.get()[0]['id'], message=self.message, random_id=0)

    def get_me(self) -> list:
        """
        Get all information about yourself

        Return:
            list: account information
        """
        return self.vk.users.get()[0]

    def set_image(self, path: str) -> None:
        """
        Attach image to message

        Args:
            path (str): image path
        """
        if Path(path).is_file() and (Path(path).suffix == ".png" or Path(path).suffix == ".jpg"
                                     or Path(path).suffix == ".jpeg"):
            upload = vk_api.VkUpload(self.vk)
            photo = upload.photo_messages(path)
            owner_id = photo[0]['owner_id']
            photo_id = photo[0]['id']
            access_key = photo[0]['access_key']
            self.image = f'photo{owner_id}_{photo_id}_{access_key}'

    def start_selective_spam(self,
                             chats: list,
                             message: str = None,
                             image: str = None,
                             delay_time: float = 1
                             ) -> None:
        """
        Start mailing to all elements of the array (1 message each)

        Args:
            chats (list): ID of all users
            message (str): set a text message
            image (str): set image to message
            delay_time (float): delay time between sending emails
        """
        if message is not None:
            self.set_message(message)
        if image is not None:
            self.set_image(image)

        with alive_bar(len(chats), force_tty=True) as bar:
            for id in chats:
                if str(abs(id)).isdigit():
                    if self.image is None:
                        self.vk.messages.send(user_id=abs(id), message=self.message, random_id=0)
                        time.sleep(delay_time)
                        bar()
                    else:
                        self.vk.messages.send(user_id=abs(id), message=self.message, random_id=0,
                                              attachment=self.image)
                        time.sleep(delay_time)
                        bar()
                else:
                    print(f'{id} is not ID')

    def start_all_spam(self,
                       message: str = None,
                       image: str = None,
                       delay_time: float = 1
                       ) -> None:
        """
        Start sending to all chats you've ever interacted in

        Args:
            message (str): set a text message
            image (str): set image to message
            delay_time (float): delay time between sending emails
        """
        if message is not None:
            self.set_message(message)
        if image is not None:
            self.set_image(image)

        chats = self.get_chats_id()
        with alive_bar(len(chats), force_tty=True) as bar:
            for chat in chats:
                if self.image is None:
                    self.vk.messages.send(user_id=abs(chat), message=self.message, random_id=0)
                    time.sleep(delay_time)
                    bar()
                else:
                    self.vk.messages.send(user_id=abs(chat), message=self.message, random_id=0,
                                          attachment=self.image)
                    time.sleep(delay_time)
                    bar()

    def start_bombing(self,
                      user_id: int,
                      amount: int,
                      message: str = None,
                      image: str = None,
                      delay_time: float = 1
                      ) -> None:
        """
        Start bombarding one user with messages

        Args:
             user_id (int): user ID
             amount (int): number of sent messages
             message (str): set a text message
             image (str): set image to message
             delay_time (float): delay time between sending emails
        """
        if message is not None:
            self.set_message(message)
        if image is not None:
            self.set_image(image)

        with alive_bar(amount, force_tty=True) as bar:
            for i in range(amount):
                if self.image is not None:
                    self.vk.messages.send(user_id=abs(user_id), message=self.message, random_id=0,
                                          attachment=self.image)
                    time.sleep(delay_time)
                    bar()
                else:
                    self.vk.messages.send(user_id=abs(user_id), message=self.message, random_id=0)
                    time.sleep(delay_time)
                    bar()

    def send_message(self,
                     user_id: int,
                     message: str = None,
                     image: str = None
                     ) -> None:
        """
        Normally send a message to a user

        Args:
            user_id (int): user ID
            message (str): set a text message
            image (str): set image to message
        """
        if message is not None:
            self.set_message(message)
        if image is not None:
            self.set_image(image)

        if self.image is not None:
            self.vk.messages.send(user_id=abs(user_id), message=self.message, random_id=0,
                                  attachment=self.image)
        else:
            self.vk.messages.send(user_id=abs(user_id), message=self.message, random_id=0)



import mimetypes
import smtplib
import time
import os
from email import encoders
from email.mime.application import MIMEApplication
from email.mime.audio import MIMEAudio
from email.mime.base import MIMEBase
from email.mime.image import MIMEImage

from email.mime.multipart import MIMEMultipart
from email.mime.text import MIMEText
from email.header import Header
from alive_progress import alive_bar


class Mail:

    def __init__(self) -> None:
        """
        Class for sending messages from mail to mail
        """
        self.mail_receiver = None
        self.username = None
        self.password = None
        self.server = smtplib.SMTP_SSL('smtp.mail.ru', 465)
        self.message = MIMEMultipart()

    def set_message(self, header: str, message: str, attachments: list = None) -> None:
        """
        Create messages for further sending in a letter

        Args:
             header (str): header of your message
             message (str): message text
             attachments (list): add attachments to email
        """
        self.message.attach(MIMEText(message, 'plain', 'utf-8'))
        self.message['Subject'] = Header(header, 'utf-8')
        if attachments:
            self.__attach_attachments(attachments=attachments)

    def set_message_html(self, header: str, html_path: str, attachments: list = None):
        """
        Creating a letter according to the layout from the html file

        Args:
             header (str): header of your message
             html_path (str): path to html file
             attachments (list): add attachments to email
        """
        try:
            with open(html_path) as file:
                html_template = file.read()
        except IOError:
            html_template = None

        self.message['Subject'] = Header(header, 'utf-8')
        self.message.attach(MIMEText(html_template, "html"))
        if attachments:
            self.__attach_attachments(attachments=attachments)

    def __attach_attachments(self, attachments: list) -> None:
        """
        Function for attaching attachments to a letter

         Args:
              attachments (list): add attachments to email
        """
        for attach in attachments:
            file_name = os.path.basename(attach)
            ftype, encoding = mimetypes.guess_type(attach)
            file_type, subtype = ftype.split("/")

            if file_type == "text":
                with open(attach, encoding="utf-8") as f:
                    file = MIMEText(f.read())
            elif file_type == "image":
                with open(attach, "rb") as f:
                    file = MIMEImage(f.read(), subtype)
            elif file_type == "audio":
                with open(attach, "rb") as f:
                    file = MIMEAudio(f.read(), subtype)
            elif file_type == "application":
                with open(attach, "rb") as f:
                    file = MIMEApplication(f.read(), subtype)
            else:
                with open(attach, "rb") as f:
                    file = MIMEBase(file_type, subtype)
                    file.set_payload(f.read())
                    encoders.encode_base64(file)

            file.add_header('content-disposition', 'attachment', filename=file_name)
            self.message.attach(file)

    def set_server(self, smtp: str, port: int) -> None:
        """
        Change SMTP server for sending messages
        Default: smtp.mail.ru:465

        Args:
            smtp (str): smtp address
            port (int): port to smtp
        """
        self.server = smtplib.SMTP_SSL(smtp, port)

    def connect_mail(self, username: str, password: str) -> None:
        """
        Connect your mail account
        * use a separate password for applications as a password

        Args:
            username (str): account login
            password (str): account password
        """
        self.username = username
        self.password = password
        self.message["From"] = username

    def send_message(self, mail_receiver: str) -> None:
        """
        Normally send a message to a user

        Args:
            mail_receiver (str): email
        """
        self.server.login(self.username, self.password)
        self.server.sendmail(self.username, mail_receiver, self.message.as_string())
        self.server.quit()

    def spam_messages(self, mail_receiver: list, delay_time: float = 1) -> None:
        """
        Start mailing to all elements of the array (1 message each)

        Args:
            mail_receiver (list): everyone's email
            delay_time (float): delay time between sending emails
        """
        self.server.login(self.username, self.password)
        with alive_bar(len(mail_receiver), force_tty=True) as bar:
            for user in mail_receiver:
                self.server.sendmail(self.username, user, self.message.as_string())
                time.sleep(delay_time)
                bar()
        self.server.quit()

    def bombing_message(self, mail_receiver: str, amount: int, delay_time: float = 1) -> None:
        """
        Start bombarding one user with messages

        Args:
             mail_receiver (str): email
             amount (int): number of sent messages
             delay_time (float): delay time between sending emails
        """
        self.server.login(self.username, self.password)
        with alive_bar(amount, force_tty=True) as bar:
            for i in range(amount):
                self.server.sendmail(self.username, mail_receiver, self.message.as_string())
                time.sleep(delay_time)
                bar()
        self.server.quit()



import pywhatkit

from alive_progress import alive_bar


class WhatsApp:

    def __init__(self) -> None:
        """
        Class for working with messages in WhatsApp
        using the module pywhatkit
        """
        self.phones = None
        self.image = None
        self.message = None

    def send_message(self,
                     phone: str = None,
                     text: str = None,
                     image: str = None
                     ) -> None:
        """
        Normally send a message to a user

        Args:
            phone (str): recipient number
            text (str): set a text message
            image (str): set image to message
        """
        if phone is not None:
            self.phones = phone
        if text is not None:
            self.message = text
        if image is not None:
            self.image = image

        if self.image is None:
            pywhatkit.sendwhatmsg_instantly(phone_no=self.phones, message=self.message,
                                            tab_close=True, close_time=1, wait_time=6)
        else:
            pywhatkit.sendwhats_image(receiver=self.phones, img_path=self.image, caption=self.message,
                                      tab_close=True, close_time=1, wait_time=6)

    def start_bombing(self,
                      phone_number: str,
                      amount: int,
                      text: str = None,
                      image: str = None
                      ) -> None:
        """
        Start bombarding one user with messages

        Args:
            phone_number (str): recipient number
            amount (int): number of sent messages
            text (str): message text
            image (str): message image
        """
        if text is not None:
            self.message = text
        if image is not None:
            self.image = image

        with alive_bar(amount, force_tty=True) as bar:
            for i in range(amount):
                pywhatkit.sendwhatmsg_instantly(phone_no=phone_number, message=self.message,
                                                tab_close=True, close_time=1, wait_time=6)
                bar()

    def start_spamming(self,
                       phones: list = None,
                       text: str = None,
                       image: str = None
                       ) -> None:
        """
        Start mailing to all elements of the array (1 message each)

        Args:
             phones (list): list of recipient numbers
             text (str): message text
             image (str): message image
        """
        if phones is not None:
            self.phones = phones
        if text is not None:
            self.message = text
        if image is not None:
            self.image = image

        with alive_bar(range(len(self.phones)), force_tty=True) as bar:
            for phone in self.phones:
                pywhatkit.sendwhatmsg_instantly(phone_no=phone, message=self.message,
                                                tab_close=True, close_time=1, wait_time=6)
                bar()

    def set_message(self, message: str) -> None:
        """
        Set the message to be used in further mailing

        Args:
            message (str): message text
        """
        self.message = message

    def set_image(self, path) -> None:
        """
        Attach image to message

        Args:
            path (str): image path
        """
        self.image = path

    def set_phone(self, phone_number: str) -> None:
        """
        Specify the number of one recipient

        Args:
            phone_number (str): recipient number
        """
        self.phones = phone_number

    def set_phones(self, phone_numbers: list) -> None:
        """
        Set a list of recipient numbers

        Args:
            phone_numbers (list): list of recipient numbers
        """
        self.phones = phone_numbers



"""
:authors: neluckoff
:email: neluckoff@gmail.com

:copyright: (c) 2022 neluckoff
"""

from .telegram import Telegram
from .vkontakte import Vkontakte
from .mail import Mail
from .whatsapp import WhatsApp

__author__ = 'neluckoff'
__version__ = '1.2.4'
__email__ = 'neluckoff@gmail.com'



from io import open
from setuptools import setup

version = '1.2.4'

with open('README.md', encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='social_spam',
    version=version,

    author='neluckoff',
    author_email='neluckoff@gmail.com',

    description=(
        u'Package for convenient work with messages in all popular instant messengers '
        u'On the current version, you have access to the following messengers: Telegram, WhatsApp, Vkontakte, Email '
    ),
    long_description=long_description,
    long_description_content_type='text/markdown',

    url='https://github.com/neluckoff/social_spam/archive/main.zip',
    download_url='https://github.com/neluckoff/social_spam/archive/master.zip',

    license='MIT License, see LICENSE file',

    packages=['social_spam'],
    install_requires=['alive_progress', 'pyrogram', 'vk-api', 'pywhatkit', 'TgCrypto'],

    classifiers=[
        'License :: OSI Approved :: MIT License',
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
        'Intended Audience :: End Users/Desktop',
        'Intended Audience :: Developers',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ]
)
